==> mdm-rpc-0.0.31-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/ProductSettlePriceVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 产品结算价
 * Created by wangfl on 2017/6/6.
 */
public class ProductSettlePriceVo implements Serializable {
    private static final long serialVersionUID = -5835191251455171765L;
    /**
     * 产品编码
     */
    private String productCode;

    /**
     * 价格类型编码
     */
    private String priceTypeCode;

    /**
     * 价格类型名称
     */
    private String priceTypeName;

    /**
     * 价格
     */
    private String price;

    /**
     * 价格单位
     */
    private String unit;

    /**
     * 货币
     */
    private String currency;

    /**
     * 数量
     */
    private long num;

    /**
     * 状态 0删除 1正常
     */
    private Integer enableStatus;

    /**
     * 有效开始时间
     */
    private Date startDate;

    /**
     * 有效结束时间
     */
    private Date endDate;

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getPriceTypeCode() {
        return priceTypeCode;
    }

    public void setPriceTypeCode(String priceTypeCode) {
        this.priceTypeCode = priceTypeCode;
    }

    public String getPriceTypeName() {
        return priceTypeName;
    }

    public void setPriceTypeName(String priceTypeName) {
        this.priceTypeName = priceTypeName;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        BigDecimal p = new BigDecimal(price);
        this.price = p.divide(new BigDecimal(100), 2, BigDecimal.ROUND_HALF_UP).toString();
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public long getNum() {
        return num;
    }

    public void setNum(long num) {
        this.num = num;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}

==> mdm-rpc-0.1.105-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/ProductSettlePriceVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;
import java.util.Date;

/**
 * 产品结算价
 * Created by wangfl on 2017/6/6.
 */
public class ProductSettlePriceVo implements Serializable {
    private static final long serialVersionUID = -5835191251455171765L;
    /**
     * 产品编码
     */
    private String productCode;

    /**
     * 价格类型编码
     */
    private String priceTypeCode;

    /**
     * 价格类型名称
     */
    private String priceTypeName;

    /**
     * 价格
     */
    private long price;

    /**
     * 价格单位
     */
    private String unit;

    /**
     * 货币
     */
    private String currency;

    /**
     * 数量
     */
    private long num;

    /**
     * 状态 0删除 1正常
     */
    private Integer enableStatus;

    /**
     * 有效开始时间
     */
    private Date startDate;

    /**
     * 有效结束时间
     */
    private Date endDate;

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getPriceTypeCode() {
        return priceTypeCode;
    }

    public void setPriceTypeCode(String priceTypeCode) {
        this.priceTypeCode = priceTypeCode;
    }

    public String getPriceTypeName() {
        return priceTypeName;
    }

    public void setPriceTypeName(String priceTypeName) {
        this.priceTypeName = priceTypeName;
    }

    public long getPrice() {
        return price;
    }

    public void setPrice(long price) {
        this.price = price;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public long getNum() {
        return num;
    }

    public void setNum(long num) {
        this.num = num;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}
